@@ -760,7 +760,8 @@ remove_active_server (ObjectDirectory *od,
 			break;
 		}
 
-	od->n_active_servers--;
+	if (removed)
+		od->n_active_servers--;
 
 	if (servers->n_servers == 0)
 		g_hash_table_remove (od->active_server_lists, iid);
@@ -821,7 +822,7 @@ od_register_runtime_server_info (ObjectDirectory  *od,
                                       od->attr_servers->_buffer + i);
          od->time_list_changed = time (NULL);
          activation_clients_cache_notify ();
-         return old_serverinfo;
+         return new_serverinfo;
 }
 
 static Bonobo_RegistrationResult
